@@ -25,26 +25,24 @@ class ListActionsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'oos', '2019-06-01', 'ListActions','oos')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_OOSActionName(self):
+	def get_OOSActionName(self): # String
 		return self.get_query_params().get('OOSActionName')
 
-	def set_OOSActionName(self,OOSActionName):
-		self.add_query_param('OOSActionName',OOSActionName)
-
-	def get_NextToken(self):
+	def set_OOSActionName(self, OOSActionName):  # String
+		self.add_query_param('OOSActionName', OOSActionName)
+	def get_NextToken(self): # String
 		return self.get_query_params().get('NextToken')
 
-	def set_NextToken(self,NextToken):
-		self.add_query_param('NextToken',NextToken)
-
-	def get_MaxResults(self):
+	def set_NextToken(self, NextToken):  # String
+		self.add_query_param('NextToken', NextToken)
+	def get_MaxResults(self): # Integer
 		return self.get_query_params().get('MaxResults')
 
-	def set_MaxResults(self,MaxResults):
-		self.add_query_param('MaxResults',MaxResults)
\ No newline at end of file
+	def set_MaxResults(self, MaxResults):  # Integer
+		self.add_query_param('MaxResults', MaxResults)
