@@ -25,62 +25,54 @@ class NotifyExecutionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'oos', '2019-06-01', 'NotifyExecution','oos')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TaskName(self):
+	def get_TaskName(self): # String
 		return self.get_query_params().get('TaskName')
 
-	def set_TaskName(self,TaskName):
-		self.add_query_param('TaskName',TaskName)
-
-	def get_ExecutionId(self):
+	def set_TaskName(self, TaskName):  # String
+		self.add_query_param('TaskName', TaskName)
+	def get_ExecutionId(self): # String
 		return self.get_query_params().get('ExecutionId')
 
-	def set_ExecutionId(self,ExecutionId):
-		self.add_query_param('ExecutionId',ExecutionId)
-
-	def get_NotifyType(self):
+	def set_ExecutionId(self, ExecutionId):  # String
+		self.add_query_param('ExecutionId', ExecutionId)
+	def get_NotifyType(self): # String
 		return self.get_query_params().get('NotifyType')
 
-	def set_NotifyType(self,NotifyType):
-		self.add_query_param('NotifyType',NotifyType)
-
-	def get_ExecutionStatus(self):
+	def set_NotifyType(self, NotifyType):  # String
+		self.add_query_param('NotifyType', NotifyType)
+	def get_ExecutionStatus(self): # String
 		return self.get_query_params().get('ExecutionStatus')
 
-	def set_ExecutionStatus(self,ExecutionStatus):
-		self.add_query_param('ExecutionStatus',ExecutionStatus)
-
-	def get_NotifyNote(self):
+	def set_ExecutionStatus(self, ExecutionStatus):  # String
+		self.add_query_param('ExecutionStatus', ExecutionStatus)
+	def get_NotifyNote(self): # String
 		return self.get_query_params().get('NotifyNote')
 
-	def set_NotifyNote(self,NotifyNote):
-		self.add_query_param('NotifyNote',NotifyNote)
-
-	def get_LoopItem(self):
+	def set_NotifyNote(self, NotifyNote):  # String
+		self.add_query_param('NotifyNote', NotifyNote)
+	def get_LoopItem(self): # String
 		return self.get_query_params().get('LoopItem')
 
-	def set_LoopItem(self,LoopItem):
-		self.add_query_param('LoopItem',LoopItem)
-
-	def get_TaskExecutionIds(self):
+	def set_LoopItem(self, LoopItem):  # String
+		self.add_query_param('LoopItem', LoopItem)
+	def get_TaskExecutionIds(self): # String
 		return self.get_query_params().get('TaskExecutionIds')
 
-	def set_TaskExecutionIds(self,TaskExecutionIds):
-		self.add_query_param('TaskExecutionIds',TaskExecutionIds)
-
-	def get_TaskExecutionId(self):
+	def set_TaskExecutionIds(self, TaskExecutionIds):  # String
+		self.add_query_param('TaskExecutionIds', TaskExecutionIds)
+	def get_TaskExecutionId(self): # String
 		return self.get_query_params().get('TaskExecutionId')
 
-	def set_TaskExecutionId(self,TaskExecutionId):
-		self.add_query_param('TaskExecutionId',TaskExecutionId)
-
-	def get_Parameters(self):
+	def set_TaskExecutionId(self, TaskExecutionId):  # String
+		self.add_query_param('TaskExecutionId', TaskExecutionId)
+	def get_Parameters(self): # String
 		return self.get_query_params().get('Parameters')
 
-	def set_Parameters(self,Parameters):
-		self.add_query_param('Parameters',Parameters)
\ No newline at end of file
+	def set_Parameters(self, Parameters):  # String
+		self.add_query_param('Parameters', Parameters)
