@@ -25,32 +25,29 @@ class TriggerExecutionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'oos', '2019-06-01', 'TriggerExecution','oos')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClientToken(self):
+	def get_ClientToken(self): # String
 		return self.get_query_params().get('ClientToken')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
-	def get_Type(self):
+	def set_ClientToken(self, ClientToken):  # String
+		self.add_query_param('ClientToken', ClientToken)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_Content(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_Content(self): # String
 		return self.get_query_params().get('Content')
 
-	def set_Content(self,Content):
-		self.add_query_param('Content',Content)
-
-	def get_ExecutionId(self):
+	def set_Content(self, Content):  # String
+		self.add_query_param('Content', Content)
+	def get_ExecutionId(self): # String
 		return self.get_query_params().get('ExecutionId')
 
-	def set_ExecutionId(self,ExecutionId):
-		self.add_query_param('ExecutionId',ExecutionId)
\ No newline at end of file
+	def set_ExecutionId(self, ExecutionId):  # String
+		self.add_query_param('ExecutionId', ExecutionId)
