@@ -25,32 +25,34 @@ class UpdateTemplateRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'oos', '2019-06-01', 'UpdateTemplate','oos')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Content(self):
+	def get_Content(self): # String
 		return self.get_query_params().get('Content')
 
-	def set_Content(self,Content):
-		self.add_query_param('Content',Content)
-
-	def get_Tags(self):
+	def set_Content(self, Content):  # String
+		self.add_query_param('Content', Content)
+	def get_Tags(self): # Json
 		return self.get_query_params().get('Tags')
 
-	def set_Tags(self,Tags):
-		self.add_query_param('Tags',Tags)
+	def set_Tags(self, Tags):  # Json
+		self.add_query_param('Tags', Tags)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
 
-	def get_TemplateName(self):
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_TemplateName(self): # String
 		return self.get_query_params().get('TemplateName')
 
-	def set_TemplateName(self,TemplateName):
-		self.add_query_param('TemplateName',TemplateName)
-
-	def get_VersionName(self):
+	def set_TemplateName(self, TemplateName):  # String
+		self.add_query_param('TemplateName', TemplateName)
+	def get_VersionName(self): # String
 		return self.get_query_params().get('VersionName')
 
-	def set_VersionName(self,VersionName):
-		self.add_query_param('VersionName',VersionName)
\ No newline at end of file
+	def set_VersionName(self, VersionName):  # String
+		self.add_query_param('VersionName', VersionName)
